@@ -82,7 +82,7 @@ role {
 		lazy     => 1,
 		default  => sub {
 			my $self      = shift;
-			my $stage_dir = $self->stage->dir;
+			my $stage_dir = $self->stage->stage_dir;
 			my $run_dir   = $stage_dir->subdir( $self->index );
 			HPCI::_trigger_mkdir( $self, $run_dir );
 			my $sym = $stage_dir->file('final_retry');
