@@ -284,20 +284,43 @@ sub assert_command_filled {
         unless $self->_has_command;
 }
 
-has 'dir' => (
+has 'stage_dir_name' => (
+    is      => 'ro',
+    isa     => 'Str',
+    lazy    => 1,
+    default => sub {
+        my $self   = shift;
+		return $self->name;
+    },
+);
+
+has 'stage_dir' => (
     is      => 'ro',
     isa     => Dir,
     coerce  => 1,
     lazy    => 1,
     default => sub {
         my $self   = shift;
-        my $target = $self->group->group_dir->subdir( $self->name );
+        my $target;
+		if ($self->_has_dir) {
+			$target = $self->dir;
+		}
+		else {
+			$target = $self->group->group_dir->subdir( $self->stage_dir_name );
+		}
         HPCI::_trigger_mkdir($self,$target);
         return $target;
     },
     trigger => \&HPCI::_trigger_mkdir,
 );
 
+has 'dir' => (
+    is      => 'ro',
+    isa     => Dir,
+    coerce  => 1,
+	predicate => '_has_dir'
+);
+
 =head2 resources_required
 
 A hash that maps resource names to the amount of that resource
